##### Developed by Lisa Sullivan, 2019 #####

######################################
########## PART 1: R BASICS ##########
######################################

##########################
######## PACKAGES ########

##### PACKAGE INSTALLATION #####
?install.packages
install.packages('stringr')
install.packages('tidyverse')

##### LOAD PACKAGES #####
?library
library(stringr)
library(tidyverse)

##########################

################################################
######## LOADING, VIEWING & SAVING DATA ########

##### SET YOUR DIRECTORY #####
setwd("~/Documents/R Workshop")

##### LOAD YOUR DATA #####
read.delim("names.txt",header=T,as.is = T, comment.char = "#" )->dat

##### VIEW YOUR DATA #####
head(dat)
dat
summary(dat)
dat %>% as_tibble()
dat %>% as_tibble() ->dat

##### SAVE YOUR DATA #####
write.table(dat,paste("names_", format(Sys.time(), "%Y%m%d_%H%M%S"), ".txt", sep=""),sep="\t",row.names=FALSE)

################################################

###############################################
########## PART 2: DATA MANIPULATION ##########
###############################################

##########################################
######## INITIAL AND FINAL SOUNDS ########

##### EXTRACT INITIAL SOUND #####
dat %>% mutate(initial = gsub("-.*$", "", Rtranscription), 
               initial = gsub("_.*$", "", initial), 
               initial = gsub("1.*$", "", initial)) -> 
  dat
dat

##### CODE INITIAL SOUND AS CONSONANT OR VOWEL #####
dat %>% 
  mutate(initialType = ifelse(initial == "i" | 
                                initial == "ɪ" | 
                                initial == "e" | 
                                initial == "ɛ" | 
                                initial == "ɑ" |
                                initial == "æ" |
                                initial == "ə" | 
                                initial == "u" | 
                                initial == "ʊ" | 
                                initial == "o" | 
                                initial == "ʌ" | 
                                initial == "a" | 
                                initial == "ɔ" |
                                initial == "aj", "V", "C")) -> 
  dat
dat

##### EXTRACT FINAL SOUND #####
dat %>% mutate(final = gsub(".*.-", "", Rtranscription),
               final = gsub(".*._", "", final),
               final = gsub("1.*$", "", final)) -> 
  dat
dat

##### CODE FINAL SOUND AS CONSONANT OR VOWEL #####
dat %>% 
  mutate(finalType = ifelse(final == "i" | 
                              final == "ɪ" | 
                              final == "e" | 
                              final == "ɛ" | 
                              final == "ɑ" |
                              final == "æ" |
                              final == "ə" | 
                              final == "u" | 
                              final == "ʊ" | 
                              final == "o" | 
                              final == "ʌ" | 
                              final == "a" | 
                              final == "ɔ" |
                              final == "aj", "V", "C")) -> 
  dat
dat

##########################################

#############################################
######## INITIAL AND FINAL SYLLABLES ########

##### INITAL SYLLABLE TYPE #####

dat %>% mutate(initSyll = gsub("_.*", "", Rtranscription),
               initSyll = gsub(".*.-", "", initSyll),
               initSyll = gsub("1.*$", "", initSyll),
               initSyllType = ifelse(initSyll == "i" | 
                                       initSyll == "ɪ" | 
                                       initSyll == "e" | 
                                       initSyll == "ɛ" | 
                                       initSyll == "ɑ" |
                                       initSyll == "æ" |
                                       initSyll == "ə" | 
                                       initSyll == "u" | 
                                       initSyll == "ʊ" | 
                                       initSyll == "o" | 
                                       initSyll == "ʌ" | 
                                       initSyll == "a"| 
                                       initSyll == "ɔ" |
                                       initSyll == "aj", "Open", "Closed"))-> 
  dat
dat

##### FINAL SYLLABLE TYPE #####

dat %>% mutate(finalSyllType = ifelse(finalType == "V", "Open", "Closed"))-> 
  dat
dat

#############################################

###############################################################
######## COUNT SYLLABLES, SEGMENTS, VOWELS, CONSONANTS ########

##### COUNT SYLLABLES #####
dat %>% 
  mutate(syllables = str_count(Rtranscription, "_") + 1) -> 
  dat
dat

##### COUNT SEGMENTS #####
dat %>% 
  mutate(segments = str_count(Rtranscription, "_|-") + 1) -> 
  dat
dat

##### COUNT VOWELS #####
dat %>% 
  mutate(vowels = str_count(Rtranscription, "i|ɪ|e|ɛ|ɑ|æ|ə|u|ʊ|o|ʌ|a|ɔ")) -> 
  dat
dat

##### COUNT CONSONANTS #####
dat %>% 
  mutate(consonants = segments-vowels) -> 
  dat
dat

###############################################################

############################################
######## ROUND AND SHARP CONSONANTS ########

##### COUNT ROUND CONSONANTS #####

dat %>% mutate(roundC = str_count(Rtranscription, "l|m|n")) -> dat
dat

##### CALCULATE PROPORTION OF CONSONANTS THAT ARE ROUND #####

dat %>% mutate(roundCProp = roundC/consonants) -> dat
dat

##### COUNT SHARP CONSONANTS #####

dat %>% mutate(sharpC = str_count(Rtranscription, "p|t|k")) -> dat
dat

##### CALCULATE PROPORTION OF CONSONANTS THAT ARE SHARP #####

dat %>% mutate(sharpCProp = sharpC/consonants) -> dat
dat

############################################

#################################
######## STRESS LOCATION ########

dat %>% 
  mutate(pstress = gsub("1.*$", "", Rtranscription), 
         stress = str_count(pstress, "_") + 1) %>%
  select(-pstress) -> 
  dat
dat

#################################

####################################################
########## PART 3: DESCRIPTIVE STATISTICS ##########
####################################################

# initial --> Categorical
# initialType --> Categorical
# final --> Categorical
# finalType --> Categorical
# initSyllType --> Categorical
# finalSyllType --> Categorical
################################
# syllables --> Quantitative
# segments --> Quantitative
# vowels --> Quantitative
# consonants --> Quantitative
# roundC --> Quantitative
# roundCProp --> Quantitative
# sharpC --> Quantitative
# sharpCProp --> Quantitative
# stress --> Quantitative (ish)

###################################################################
######## DESSCRIPTIVE STATISTICS FOR CATEGORICAL VARIABLES ########

##### COUNTS & PROPORTIONS BY LEVEL & SEX #####
dat %>% group_by(initial) %>% summarize(Female = sum(Sex=="F"), 
                                        propF = Female/20, 
                                        Male = sum(Sex=="M"), 
                                        propM = Male/20, 
                                        Total = n(), 
                                        propT=Total/40)
dat %>% group_by(initialType) %>% summarize(Female = sum(Sex=="F"), propF = Female/20, Male = sum(Sex=="M"), propM = Male/20, Total = n(), propT=Total/40)
dat %>% group_by(initSyllType) %>% summarize(Female = sum(Sex=="F"), propF = Female/20, Male = sum(Sex=="M"), propM = Male/20, Total = n(), propT=Total/40)
dat %>% group_by(final) %>% summarize(Female = sum(Sex=="F"), propF = Female/20, Male = sum(Sex=="M"), propM = Male/20, Total = n(), propT=Total/40)
dat %>% group_by(finalType) %>% summarize(Female = sum(Sex=="F"), propF = Female/20, Male = sum(Sex=="M"), propM = Male/20, Total = n(), propT=Total/40)
dat %>% group_by(finalSyllType) %>% summarize(Female = sum(Sex=="F"), propF = Female/20, Male = sum(Sex=="M"), propM = Male/20, Total = n(), propT=Total/40)

###################################################################

##################################################################
######## DESSCRIPTIVE STATISTICS FOR CONTINUOUS VARIABLES ########

##### COUNTS & PROPORTIONS BY LEVEL & SEX #####
dat %>% group_by(syllables) %>% summarize(Female = sum(Sex=="F"), 
                                          propF = Female/20, 
                                          Male = sum(Sex=="M"), 
                                          propM = Male/20, 
                                          Total = n(), 
                                          propT=Total/40)
dat %>% group_by(segments) %>% summarize(Female = sum(Sex=="F"), propF = Female/20, Male = sum(Sex=="M"), propM = Male/20, Total = n(), propT=Total/40)
dat %>% group_by(roundCProp) %>% summarize(Female = sum(Sex=="F"), propF = Female/20, Male = sum(Sex=="M"), propM = Male/20, Total = n(), propT=Total/40)
dat %>% group_by(sharpCProp) %>% summarize(Female = sum(Sex=="F"), propF = Female/20, Male = sum(Sex=="M"), propM = Male/20, Total = n(), propT=Total/40)
dat %>% group_by(stress) %>% summarize(Female = sum(Sex=="F"), propF = Female/20, Male = sum(Sex=="M"), propM = Male/20, Total = n(), propT=Total/40)

##### SUMMARY STATISTICS (MEAN, SD, MEDIAN, MAXIMUM, MINIMUM, RANGE) #####
dat %>% group_by(Sex) %>% summarize(n = n(),
                                    mean = mean(syllables), 
                                    sd = sd(syllables), 
                                    median = median(syllables), 
                                    max = max(syllables), 
                                    min = min(syllables), 
                                    range = max-min)
dat %>% summarize(n = n(), mean = mean(syllables), sd = sd(syllables), median = median(syllables), max = max(syllables), min = min(syllables), range = max-min)

dat %>% group_by(Sex) %>% summarize(n = n(), mean = mean(segments), sd = sd(segments), median = median(segments), max = max(segments), min = min(segments), range = max-min)
dat %>% summarize(n = n(), mean = mean(segments), sd = sd(segments), median = median(segments), max = max(segments), min = min(segments), range = max-min)

dat %>% group_by(Sex) %>% summarize(n = n(), mean = mean(roundCProp), sd = sd(roundCProp), median = median(roundCProp), max = max(roundCProp), min = min(roundCProp), range = max-min)
dat %>% summarize(n = n(), mean = mean(roundCProp), sd = sd(roundCProp), median = median(roundCProp), max = max(roundCProp), min = min(roundCProp), range = max-min)

dat %>% group_by(Sex) %>% summarize(n = n(), mean = mean(sharpCProp), sd = sd(sharpCProp), median = median(sharpCProp), max = max(sharpCProp), min = min(roundCProp), range = max-min)
dat %>% summarize(n = n(), mean = mean(sharpCProp), sd = sd(sharpCProp), median = median(sharpCProp), max = max(sharpCProp), min = min(sharpCProp), range = max-min)

dat %>% group_by(Sex) %>% summarize(n = n(), mean = mean(stress), sd = sd(stress), median = median(stress), max = max(stress), min = min(stress), range = max-min)
dat %>% summarize(n = n(), mean = mean(stress), sd = sd(stress), median = median(stress), max = max(stress), min = min(stress), range = max-min)

##################################################################

#######################################################
########## PART 4: VISUALIZATION WITH GGPLOT ##########
#######################################################

# 3 Types of graphs: bar charts, boxplots, density plots
# Bar charts are good for categorical variables & some quantitative variables (but not all!!!)
# Boxplots & density plots are good for quantitative variables, not good for categorical variables

#######################################################
######### BAR CHARTS FOR CATEGORICAL VARIABLES ########

dat %>% ggplot(aes(Sex)) + geom_bar(aes(fill=initialType), position="fill") + xlab("Sex") + ylab("Proportion") + theme_bw() + scale_fill_grey() + guides(fill=guide_legend(title="Initial Segment Type"))

dat %>% ggplot(aes(Sex)) + geom_bar(aes(fill=initSyllType), position="fill") + xlab("Sex") + ylab("Proportion") + theme_bw() + scale_fill_grey() + guides(fill=guide_legend(title="Initial Syllable Type"))

dat %>% ggplot(aes(Sex)) + geom_bar(aes(fill=finalType), position="fill") + xlab("Sex") + ylab("Proportion") + theme_bw() + scale_fill_grey() + guides(fill=guide_legend(title="Final Segment Type"))

dat %>% ggplot(aes(Sex)) + geom_bar(aes(fill=finalSyllType), position="fill") + xlab("Sex") + ylab("Proportion") + theme_bw() + scale_fill_grey() + guides(fill=guide_legend(title="Final Syllable Type"))

#######################################################

#####################################################
######## BAR CHARTS FOR CONTINUOUS VARIABLES ########

dat %>% ggplot(aes(Sex)) + geom_bar(aes(fill=as.factor(as.character(syllables))), position="fill") + xlab("Sex") + ylab("Proportion") + theme_bw() + scale_fill_grey() + guides(fill=guide_legend(title="Number of Syllables"))

dat %>% ggplot(aes(Sex)) + geom_bar(aes(fill=as.factor(as.character(segments))), position="fill") + xlab("Sex") + ylab("Proportion") + theme_bw() + scale_fill_grey() + guides(fill=guide_legend(title="Number of Segments"))

dat %>% ggplot(aes(Sex)) + geom_bar(aes(fill=as.factor(as.character(roundCProp))), position="fill") + xlab("Sex") + ylab("Proportion") + theme_bw() + scale_fill_grey() + guides(fill=guide_legend(title="Proportion of Round Consonants"))

dat %>% ggplot(aes(Sex)) + geom_bar(aes(fill=as.factor(as.character(sharpCProp))), position="fill") + xlab("Sex") + ylab("Proportion") + theme_bw() + scale_fill_grey() + guides(fill=guide_legend(title="Proportion of Sharp Consonants"))

dat %>% ggplot(aes(Sex)) + geom_bar(aes(fill=as.factor(as.character(stress))), position="fill") + xlab("Sex") + ylab("Proportion") + theme_bw() + scale_fill_grey() + guides(fill=guide_legend(title="Stress Placement"))
#####################################################

###################################################
######## BOXPLOTS FOR CONTINUOUS VARIABLES ########

dat %>% ggplot(aes(Sex,syllables)) + geom_boxplot() + xlab("Sex") + ylab("Number of Syllables") + theme_bw() + scale_fill_grey()

dat %>% ggplot(aes(Sex, segments)) + geom_boxplot() + xlab("Sex") + ylab("Number of Segments") + theme_bw() + scale_fill_grey()

dat %>% ggplot(aes(Sex, vowels)) + geom_boxplot() + xlab("Sex") + ylab("Number of Vowels") + theme_bw() + scale_fill_grey()

dat %>% ggplot(aes(Sex, consonants)) + geom_boxplot() + xlab("Sex") + ylab("Number of Consonants") + theme_bw() + scale_fill_grey()

dat %>% ggplot(aes(Sex, roundC)) + geom_boxplot() + xlab("Sex") + ylab("Number of Round Consonants") + theme_bw() + scale_fill_grey()

dat %>% ggplot(aes(Sex, roundCProp)) + geom_boxplot() + xlab("Sex") + ylab("Proportion of Round Consonants") + theme_bw() + scale_fill_grey()

dat %>% ggplot(aes(Sex, sharpC)) + geom_boxplot() + xlab("Sex") + ylab("Number of Sharp Consonants") + theme_bw() + scale_fill_grey()

dat %>% ggplot(aes(Sex, sharpCProp)) + geom_boxplot() + xlab("Sex") + ylab("Proportion of Sharp Consonants") + theme_bw() + scale_fill_grey()

dat %>% ggplot(aes(Sex, stress)) + geom_boxplot() + xlab("Sex") + ylab("Stress Placement") + theme_bw() + scale_fill_grey()
###################################################

########################################################
######## DENSITY PLOTS FOR CONTINUOUS VARIABLES ########

dat %>% ggplot(aes(syllables)) + geom_density(aes(fill=Sex), alpha = 0.7, adjust=1) + xlab("Number of Syllables") + theme_bw() + scale_fill_grey()

dat %>% ggplot(aes(segments)) + geom_density(aes(fill=Sex), alpha = 0.7, adjust=1) + xlab("Number of Segments") + theme_bw() + scale_fill_grey()

dat %>% ggplot(aes(vowels)) + geom_density(aes(fill=Sex), alpha = 0.7, adjust=1) + xlab("Number of Vowels") + theme_bw() + scale_fill_grey()

dat %>% ggplot(aes(consonants)) + geom_density(aes(fill=Sex), alpha = 0.7, adjust=1) + xlab("Number of Consonants") + theme_bw() + scale_fill_grey()

dat %>% ggplot(aes(roundC)) + geom_density(aes(fill=Sex), alpha = 0.7, adjust=1) + xlab("Number of Round Consonants") + theme_bw() + scale_fill_grey()

dat %>% ggplot(aes(roundCProp)) + geom_density(aes(fill=Sex), alpha = 0.7, adjust=1) + xlab("Proportion of Round Consonants") + theme_bw() + scale_fill_grey()

dat %>% ggplot(aes(sharpC)) + geom_density(aes(fill=Sex), alpha = 0.7, adjust=1) + xlab("Number of Sharp Consonants") + theme_bw() + scale_fill_grey()

dat %>% ggplot(aes(sharpCProp)) + geom_density(aes(fill=Sex), alpha = 0.7, adjust=1) + xlab("Proportion of Sharp Consonants") + theme_bw() + scale_fill_grey()

dat %>% ggplot(aes(stress)) + geom_density(aes(fill=Sex), alpha = 0.7, adjust=1) + xlab("Stress Placement") + theme_bw() + scale_fill_grey()
########################################################